Crate utf8_bytes

Crate utf8_bytes 

A deep UTF-8 string library backed by [bytes].

Structs

FromUtf8Error
Utf8Bytes
A cheaply cloneable and sliceable chunk of contiguous memory filled with UTF-8 bytes.
Utf8BytesMut
A unique reference to a contiguous slice of UTF-8 memory.