A deep UTF-8 string library backed by [bytes].
Structs
- From
Utf8 Error - Utf8
Bytes - A cheaply cloneable and sliceable chunk of contiguous memory filled with UTF-8 bytes.
- Utf8
Bytes Mut - A unique reference to a contiguous slice of UTF-8 memory.